@@ -43,6 +43,7 @@ from atlasapi.lib import AtlasLogNames, LogLine, ProviderName, MongoDBMajorVersi
 from atlasapi.cloud_backup import CloudBackupSnapshot, CloudBackupRequest, SnapshotRestore, SnapshotRestoreResponse, \
     DeliveryType
 from requests import get
+from requests.auth import HTTPBasicAuth, HTTPDigestAuth
 import gzip
 
 logger = logging.getLogger('Atlas')
@@ -56,13 +57,15 @@ class Atlas:
         user (str): Atlas user
         password (str): Atlas password
         group (str): Atlas group
+        auth_method (Union[HTTPBasicAuth,HTTPDigestAuth]) : Athentication method to use, defaults to digest, but you
+        can override to Basic if needed for use with a Proxy.
     """
 
-    def __init__(self, user, password, group):
+    def __init__(self, user, password, group, auth_method: Union[HTTPBasicAuth, HTTPDigestAuth] = HTTPDigestAuth):
         self.group = group
 
         # Network calls which will handled user/password for auth
-        self.network = Network(user, password)
+        self.network = Network(user, password, auth_method)
 
         # APIs
         self.DatabaseUsers = Atlas._DatabaseUsers(self)
@@ -1441,7 +1444,7 @@ class Atlas:
                 AtlasPagination or dict: Iterable object representing this function OR Response payload
 
             """
-            logger.warning('Getting by snapshotid')
+            logger.info('Getting by snapshotid')
             uri = Settings.api_resources["Cloud Backup"]["Get snapshot by SNAPSHOT-ID"] \
                 .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name, SNAPSHOT_ID=snapshot_id)
 
@@ -1511,7 +1514,7 @@ class Atlas:
             except ErrAtlasBadRequest as e:
                 if e.details.get('errorCode') == 'CLUSTER_RESTORE_IN_PROGRESS_CANNOT_UPDATE':
                     logger.error(e.details)
-                    raise ErrAtlasRestoreConflictError(c=400,details=e.details)
+                    raise ErrAtlasRestoreConflictError(c=400, details=e.details)
                 else:
                     logger.error('Received an Atlas bad request on Snapshot restore request.')
                     logger.error(e.details)
@@ -1526,14 +1529,15 @@ class Atlas:
             return response_obj
 
         # Get all Cloud Backup restore jobs by cluster
-        def get_snapshot_restore_requests(self, cluster_name: str, restore_id: str = None, as_obj: bool = True):
+        def get_snapshot_restore_requests(self, cluster_name: str, restore_id: str = None, as_obj: bool = True) \
+                -> Union[List [Union[dict,SnapshotRestoreResponse]], SnapshotRestoreResponse, dict]:
 
             if not restore_id:
                 uri = Settings.api_resources["Cloud Backup Restore Jobs"][
                     "Get all Cloud Backup restore jobs by cluster"] \
                     .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name)
             else:
-                logger.warning('Getting by restore_id')
+                logger.info('Getting by restore_id')
                 uri = Settings.api_resources["Cloud Backup Restore Jobs"]["Get Cloud Backup restore job by cluster"] \
                     .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name, JOB_ID=restore_id)
 
@@ -1559,6 +1563,40 @@ class Atlas:
                     logger.debug(f'This is the {entry}')
                     yield SnapshotRestoreResponse.from_dict(entry)
 
+        def cancel_snapshot_restore_request(self, cluster_name: str, restore_id: str):
+            """
+            Cancels a current backup restore request by restore_id.
+
+            Calls:
+            https://docs.atlas.mongodb.com/reference/api/cloud-backup/restore/delete-one-restore-job/
+
+            Args:
+                cluster_name: The name of the source cluster.
+                restore_id:  The id of the (jobId) of the restore job.
+            """
+            # First Check if the restore_id is valid
+            restore_info_result: SnapshotRestoreResponse = \
+                self.get_snapshot_restore_requests(cluster_name=cluster_name,restore_id=restore_id,as_obj=True)
+            restore_info = list(restore_info_result)[0]
+            if not restore_info:
+                raise ErrAtlasNotFound(404,{"error": f"The passed restore_id {restore_id} was not found"})
+
+            elif restore_info.finished_at:
+                raise ErrAtlasBadRequest(500,{"error": f"The passed restore_id ({restore_id} has already been completed"
+                                                       f"and can not be canceled"})
+            elif restore_info.cancelled is True:
+                raise ErrAtlasConflict(500,
+                                         {"error": f"The passed restore_id ({restore_id} has already been canceled"})
+
+            else:
+                uri = Settings.api_resources["Cloud Backup Restore Jobs"]["Cancel manual download restore job by job_id"] \
+                    .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name, JOB_ID=restore_id)
+                logger.info(f'Preparing to cancel snapshot {restore_info.snapshot_id}, on'
+                            f' {restore_info.target_cluster_name} with restore_id {restore_id}.')
+
+                response = self.atlas.network.delete(Settings.BASE_URL + uri)
+
+                return response
 
 class AtlasPagination:
     """Atlas Pagination Generic Implementation
